@@ -86,11 +86,14 @@ def calculate_pix(uvw, uvcellsize, imsize, freq=None):
 
 
 class Gridder(Transformer, ABC):
-    def __init__(self, image: Image = None, imsize: Union[List[int], int] = None, uvcellsize: Quantity = None,
+    def __init__(self, image: Image = None, imsize: Union[List[int], int] = None,
+                 cellsize: Union[List[float], float, Quantity] = None,
+                 uvcellsize: Union[List[float], float, Quantity] = None,
                  ckernel_object: CKernel = None, hermitian_symmetry: bool = None, **kwargs):
         """
         Class that represents the interferometric gridding
         :param imsize: Image size
+        :para cellsize: Cell size in Image-space
         :param uvcellsize: Cell size in Fourier-space
         :param ckernel_object: Convolution Kernel
         :param hermitian_symmetry : Indicated whether hermitian symmetry has been applied or not
@@ -99,37 +102,102 @@ class Gridder(Transformer, ABC):
         super().__init__(**kwargs)
         self.ckernel_object = ckernel_object
         self.image = image
+        self.hermitian_symmetry = hermitian_symmetry
 
-        if hermitian_symmetry is None:
+        if self.hermitian_symmetry is None:
             self.hermitian_symmetry = False
-        else:
-            self.hermitian_symmetry = hermitian_symmetry
 
         if image is None:
-            if isinstance(imsize, int):
-                if self.hermitian_symmetry:
-                    self.imsize = [imsize, imsize // 2 + 1]
-                else:
-                    self.imsize = [imsize, imsize]
+            self.imsize = imsize
+            if cellsize is None and uvcellsize is not None:
+                self.uvcellsize = uvcellsize
+            elif cellsize is not None and uvcellsize is None:
+                self.cellsize = cellsize
+            elif cellsize is not None and uvcellsize is not None:
+                self.cellsize = cellsize
             else:
-                if self.hermitian_symmetry:
-                    if imsize[0] == imsize[1]:
-                        self.imsize = [imsize[0], imsize[1] // 2 + 1]
-                    else:
-                        self.imsize = imsize
-                else:
-                    self.imsize = imsize
+                self.cellsize = cellsize
+                self.uvcellsize = uvcellsize
 
-            if isinstance(uvcellsize, Quantity):
-                if uvcellsize.shape[0] > 1:
-                    self.uvcellsize = uvcellsize
-                else:
-                    self.uvcellsize = Quantity([uvcellsize, uvcellsize, uvcellsize])
-            else:
-                raise TypeError("uvcellsize must be a Quantity instance")
         else:
             self.imsize = image.imsize
-            self.uvcellsize = image.cellsize.to(un.lambdas, equivalencies=lambdas_equivalencies()) / self.imsize
+            self.cellsize = image.cellsize
+
+    @property
+    def imsize(self):
+        return self.__imsize
+
+    @imsize.setter
+    def imsize(self, imsize):
+        if isinstance(imsize, int):
+            if self.hermitian_symmetry:
+                self.__imsize = [imsize, imsize // 2 + 1]
+            else:
+                self.__imsize = [imsize, imsize]
+        else:
+            if self.hermitian_symmetry:
+                if imsize[0] == imsize[1]:
+                    self.__imsize = [imsize[0], imsize[1] // 2 + 1]
+                else:
+                    self.__imsize = imsize
+            else:
+                self.__imsize = imsize
+
+    @property
+    def cellsize(self):
+        return self.__cellsize
+
+    @cellsize.setter
+    def cellsize(self, cellsize):
+        if isinstance(cellsize, Quantity):
+            if len(cellsize) > 1:
+                self.__cellsize = cellsize
+            else:
+                self.__cellsize = Quantity([cellsize, cellsize])
+        elif isinstance(cellsize, float):
+            self.__cellsize = Quantity([cellsize * un.rad, cellsize * un.rad])
+        elif isinstance(cellsize, list):
+            if cellsize and len(cellsize) <= 2:
+                self.__cellsize = Quantity(cellsize * un.rad)
+            else:
+                ValueError("The provided list for uvcellsize is too big for Gridder")
+        else:
+            self.__cellsize = cellsize
+
+        if self.__cellsize is not None and self.__imsize is not None:
+            if self.hermitian_symmetry:
+                imsize = [self.__imsize[0], (self.__imsize[1] - 1) * 2]
+            else:
+                imsize = self.__imsize
+            self.__uvcellsize = (1 / (imsize * self.__cellsize)).to(un.lambdas, equivalencies=lambdas_equivalencies())
+
+    @property
+    def uvcellsize(self):
+        return self.__uvcellsize
+
+    @uvcellsize.setter
+    def uvcellsize(self, uvcellsize):
+        if isinstance(uvcellsize, Quantity):
+            if len(uvcellsize) > 1:
+                self.__uvcellsize = uvcellsize
+            else:
+                self.__uvcellsize = Quantity([uvcellsize, uvcellsize])
+        elif isinstance(uvcellsize, float):
+            self.__uvcellsize = Quantity([uvcellsize * un.lambdas, uvcellsize * un.lambdas])
+        elif isinstance(uvcellsize, list):
+            if uvcellsize and len(uvcellsize) <= 2:
+                self.__uvcellsize = Quantity(uvcellsize * un.lambdas)
+            else:
+                ValueError("The provided list for uvcellsize is too big for Gridder")
+        else:
+            self.__uvcellsize = uvcellsize
+
+        if self.__uvcellsize is not None and self.imsize is not None:
+            if self.hermitian_symmetry:
+                imsize = [self.__imsize[0], (self.__imsize[1] - 1) * 2]
+            else:
+                imsize = self.__imsize
+            self.__cellsize = (1 / (imsize * self.__uvcellsize)).to(un.rad, equivalencies=lambdas_equivalencies())
 
     def grid_weights(self, ms: MS = None, max_nu: Quantity = None):
 
