@@ -15,9 +15,10 @@ class Uniform(WeightingScheme, ABC):
         """
         if self.gridder is not None:
             dataset = self.input_data
+            max_nu = dataset.max_nu
             for ms in dataset.ms_list:
                 weight = ms.visibilities.weight
-                idx, bin_count, w_k = self.gridder.grid_weights(ms)
+                idx, bin_count, w_k = self.gridder.grid_weights(ms, max_nu)
                 weight /= w_k
         else:
             raise TypeError("gridding attribute cannot be None when calculting uniform weights")
